@@ -7,4 +7,4 @@ dataModelCreator <- function(){
   return(list(data=data, model = model))
 }
 
-benchmarkUniformity(dataModelCreator = dataModelCreator, nSim = 5)
+\dontrun{benchmarkUniformity(dataModelCreator = dataModelCreator, nSim = 4)}
